
tw (textwarden)
==================================================
[![PyPI version](https://badge.fury.io/py/textwarden.svg)](https://badge.fury.io/py/textwarden)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

Generic Discord bot.

Overview
-------------------------

TODO

Installation
-------------------------

### install from pypi (recommend)
`pip3 install textwarden`

### install from git (latest master)
`pip3 install -U git+https://gitlab.com/nul.one/textwarden.git`

Usage
-------------------------

TODO

